from math import sqrt
class Song(object):
    def __init__(self, path, title=None, album=None, interpreter=None, comment=None, cs=0, genres={}, length=None, chance=500, timesplayed=0,  rating=10):
        self.path = path
        self.title = title
        self.album = album
        self.interpreter = interpreter
        self.comment = comment
        self.cs = cs
        self.genres = genres
        self.length = length
        self.chance = chance
        self.timesplayed = timesplayed
        self.rating = rating
        
    def update(self, title, album, interpreter, comment,  cs, rating):
        self.title = title
        self.album = album
        self.interpreter = interpreter
        self.comment = comment
        self.cs = cs
        self.rating = rating
        
    def set_rating(self, rating):
        self.rating = rating
        
    def increasechance(self, count):
        count = float(count)
        count = float(count)
        self.chance += sqrt(self.chance) / count * (self.rating / 10.0)
        if self.chance >= 1:
            self.chance = 1
        
    def decreasechance(self, count):
        count = float(count)
        self.chance -= self.chance * self.chance * count
        if self.chance <= 0:
            self.chance = 0.000000001
        
    def update_timesplayed(self):
        self.timesplayed += 1
        
    def get_chance(self):
        return self.chance
        
    def get_title(self):
        return self.title
        
    def get_album(self):
        return self.album
        
    def get_interpreter(self):
        return self.interpreter
        
    def get_genres(self):
        return self.genres
        
    def get_path(self):
        return self.path
    
    def get_cs(self):
        return self.cs
    
    def genres_add(self, genre):
        self.genres.add(genre)
        
    def genres_del(self,  genre):
        self.genres.remove(genre)
        
    def get_all(self):
        return {'path': self.path, 'title': self.title, 'album': self.album, 'interpreter': self.interpreter, 'comment' : self.comment, 'cs': self.cs, 'genre': self.genres, 'length' : self.length, 'chance' : self.chance, 'timesplayed' : self.timesplayed, 'rating' : self.rating}



import sys
from PyQt4.QtGui import *
from PyQt4.QtCore import *

from GUI import MainWindow
app = QApplication(sys.argv)
mw = MainWindow()
mw.show()
QTimer.singleShot(0,  lambda: mw.start())
app.exec_()



from PyQt4.QtGui import *
from PyQt4.QtCore import *

class MyDropTable(QTableWidget):
    playlistInfo = pyqtSignal(str, bool)
    
    def __init__(self, parent=None):
        QTableWidget.__init__(self)
        self.setAcceptDrops(True)

    def mimeTypes(self):
        types =['application/x-songlistdata', 'text/x-moz-url']
        return types

    def dragEnterEvent(self, e):
         if e.mimeData().hasFormat('application/x-songlistdata') or e.mimeData().hasFormat('text/x-moz-url'):
            e.acceptProposedAction()

    def dragMoveEvent(self, e):
        #Funktion MUSS Ueberschrieben werden
        pass

    def dropMimeData(self, row, column, data, action):
        if data.hasFormat('application/x-songlistdata'): 
            bytearray = data.data('application/x-songlistdata')
            paths = bytearray.data().split('\\')
        else:
            paths = []
            for url in data.urls():
                paths.append(url.toString()[7:])

        for path in paths:
            self.playlistInfo.emit(path, True)
        return True



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/musicplayer.ui'
#
# Created: Thu Jul  2 14:14:04 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_music(object):
    def setupUi(self, music):
        music.setObjectName(_fromUtf8("music"))
        music.resize(653, 164)
        music.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.verticalLayout = QtGui.QVBoxLayout(music)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setSizeConstraint(QtGui.QLayout.SetDefaultConstraint)
        self.horizontalLayout_2.setContentsMargins(0, 0, -1, 0)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.dockbutton = QtGui.QToolButton(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockbutton.sizePolicy().hasHeightForWidth())
        self.dockbutton.setSizePolicy(sizePolicy)
        self.dockbutton.setMinimumSize(QtCore.QSize(0, 0))
        self.dockbutton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.dockbutton.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.dockbutton.setText(_fromUtf8(""))
        self.dockbutton.setAutoRepeat(False)
        self.dockbutton.setAutoRaise(False)
        self.dockbutton.setArrowType(QtCore.Qt.UpArrow)
        self.dockbutton.setObjectName(_fromUtf8("dockbutton"))
        self.horizontalLayout_2.addWidget(self.dockbutton)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.verticalLayout_7 = QtGui.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.label_3 = QtGui.QLabel(music)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout_7.addWidget(self.label_3)
        self.soundSlider = QtGui.QSlider(music)
        self.soundSlider.setMaximum(10)
        self.soundSlider.setProperty("value", 1)
        self.soundSlider.setOrientation(QtCore.Qt.Horizontal)
        self.soundSlider.setTickInterval(0)
        self.soundSlider.setObjectName(_fromUtf8("soundSlider"))
        self.verticalLayout_7.addWidget(self.soundSlider)
        self.horizontalLayout_3.addLayout(self.verticalLayout_7)
        self.verticalLayout_8 = QtGui.QVBoxLayout()
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.scrolltitel = QtGui.QScrollArea(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrolltitel.sizePolicy().hasHeightForWidth())
        self.scrolltitel.setSizePolicy(sizePolicy)
        self.scrolltitel.setMaximumSize(QtCore.QSize(16777215, 20))
        self.scrolltitel.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.scrolltitel.setFrameShape(QtGui.QFrame.NoFrame)
        self.scrolltitel.setFrameShadow(QtGui.QFrame.Plain)
        self.scrolltitel.setLineWidth(0)
        self.scrolltitel.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrolltitel.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrolltitel.setWidgetResizable(True)
        self.scrolltitel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.scrolltitel.setObjectName(_fromUtf8("scrolltitel"))
        self.scrollAreaWidgetContents_4 = QtGui.QWidget()
        self.scrollAreaWidgetContents_4.setGeometry(QtCore.QRect(0, 0, 475, 23))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents_4.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents_4.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents_4.setObjectName(_fromUtf8("scrollAreaWidgetContents_4"))
        self.verticalLayout_9 = QtGui.QVBoxLayout(self.scrollAreaWidgetContents_4)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.titel = QtGui.QLabel(self.scrollAreaWidgetContents_4)
        self.titel.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.titel.setAlignment(QtCore.Qt.AlignCenter)
        self.titel.setObjectName(_fromUtf8("titel"))
        self.verticalLayout_9.addWidget(self.titel)
        self.scrolltitel.setWidget(self.scrollAreaWidgetContents_4)
        self.verticalLayout_8.addWidget(self.scrolltitel)
        self.scrollinterpreter = QtGui.QScrollArea(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollinterpreter.sizePolicy().hasHeightForWidth())
        self.scrollinterpreter.setSizePolicy(sizePolicy)
        self.scrollinterpreter.setMaximumSize(QtCore.QSize(16777215, 20))
        self.scrollinterpreter.setFrameShape(QtGui.QFrame.NoFrame)
        self.scrollinterpreter.setFrameShadow(QtGui.QFrame.Plain)
        self.scrollinterpreter.setLineWidth(0)
        self.scrollinterpreter.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollinterpreter.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollinterpreter.setWidgetResizable(True)
        self.scrollinterpreter.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.scrollinterpreter.setObjectName(_fromUtf8("scrollinterpreter"))
        self.scrollAreaWidgetContents_5 = QtGui.QWidget()
        self.scrollAreaWidgetContents_5.setGeometry(QtCore.QRect(0, 0, 475, 23))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents_5.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents_5.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents_5.setObjectName(_fromUtf8("scrollAreaWidgetContents_5"))
        self.verticalLayout_10 = QtGui.QVBoxLayout(self.scrollAreaWidgetContents_5)
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.interpreter = QtGui.QLabel(self.scrollAreaWidgetContents_5)
        self.interpreter.setAlignment(QtCore.Qt.AlignCenter)
        self.interpreter.setObjectName(_fromUtf8("interpreter"))
        self.verticalLayout_10.addWidget(self.interpreter)
        self.scrollinterpreter.setWidget(self.scrollAreaWidgetContents_5)
        self.verticalLayout_8.addWidget(self.scrollinterpreter)
        self.scrollalbum = QtGui.QScrollArea(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollalbum.sizePolicy().hasHeightForWidth())
        self.scrollalbum.setSizePolicy(sizePolicy)
        self.scrollalbum.setMaximumSize(QtCore.QSize(16777215, 20))
        self.scrollalbum.setFrameShape(QtGui.QFrame.NoFrame)
        self.scrollalbum.setFrameShadow(QtGui.QFrame.Plain)
        self.scrollalbum.setLineWidth(0)
        self.scrollalbum.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollalbum.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollalbum.setWidgetResizable(True)
        self.scrollalbum.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.scrollalbum.setObjectName(_fromUtf8("scrollalbum"))
        self.scrollAreaWidgetContents_6 = QtGui.QWidget()
        self.scrollAreaWidgetContents_6.setGeometry(QtCore.QRect(0, 0, 475, 23))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAreaWidgetContents_6.sizePolicy().hasHeightForWidth())
        self.scrollAreaWidgetContents_6.setSizePolicy(sizePolicy)
        self.scrollAreaWidgetContents_6.setObjectName(_fromUtf8("scrollAreaWidgetContents_6"))
        self.verticalLayout_11 = QtGui.QVBoxLayout(self.scrollAreaWidgetContents_6)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.album = QtGui.QLabel(self.scrollAreaWidgetContents_6)
        self.album.setAlignment(QtCore.Qt.AlignCenter)
        self.album.setObjectName(_fromUtf8("album"))
        self.verticalLayout_11.addWidget(self.album)
        self.scrollalbum.setWidget(self.scrollAreaWidgetContents_6)
        self.verticalLayout_8.addWidget(self.scrollalbum)
        self.horizontalLayout_3.addLayout(self.verticalLayout_8)
        self.verticalLayout_12 = QtGui.QVBoxLayout()
        self.verticalLayout_12.setObjectName(_fromUtf8("verticalLayout_12"))
        self.label_4 = QtGui.QLabel(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setMinimumSize(QtCore.QSize(0, 0))
        self.label_4.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.label_4.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_12.addWidget(self.label_4)
        self.spinBoxRating = QtGui.QSpinBox(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBoxRating.sizePolicy().hasHeightForWidth())
        self.spinBoxRating.setSizePolicy(sizePolicy)
        self.spinBoxRating.setMinimumSize(QtCore.QSize(0, 0))
        self.spinBoxRating.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.spinBoxRating.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.spinBoxRating.setWrapping(False)
        self.spinBoxRating.setFrame(True)
        self.spinBoxRating.setAlignment(QtCore.Qt.AlignCenter)
        self.spinBoxRating.setKeyboardTracking(False)
        self.spinBoxRating.setMinimum(1)
        self.spinBoxRating.setMaximum(20)
        self.spinBoxRating.setObjectName(_fromUtf8("spinBoxRating"))
        self.verticalLayout_12.addWidget(self.spinBoxRating)
        self.horizontalLayout_3.addLayout(self.verticalLayout_12)
        self.horizontalLayout_3.setStretch(0, 1)
        self.horizontalLayout_3.setStretch(1, 6)
        self.horizontalLayout_3.setStretch(2, 1)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.timelayout = QtGui.QHBoxLayout()
        self.timelayout.setObjectName(_fromUtf8("timelayout"))
        self.progress = MyProgressbar(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.progress.sizePolicy().hasHeightForWidth())
        self.progress.setSizePolicy(sizePolicy)
        self.progress.setMinimumSize(QtCore.QSize(0, 0))
        self.progress.setMaximumSize(QtCore.QSize(16777215, 10))
        self.progress.setMouseTracking(False)
        self.progress.setProperty("value", 0)
        self.progress.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.progress.setTextVisible(False)
        self.progress.setObjectName(_fromUtf8("progress"))
        self.timelayout.addWidget(self.progress)
        self.time = QtGui.QLabel(music)
        self.time.setObjectName(_fromUtf8("time"))
        self.timelayout.addWidget(self.time)
        self.length = QtGui.QLabel(music)
        self.length.setObjectName(_fromUtf8("length"))
        self.timelayout.addWidget(self.length)
        self.verticalLayout.addLayout(self.timelayout)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.previousbutton = QtGui.QPushButton(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.previousbutton.sizePolicy().hasHeightForWidth())
        self.previousbutton.setSizePolicy(sizePolicy)
        self.previousbutton.setText(_fromUtf8(""))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/previous.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.previousbutton.setIcon(icon)
        self.previousbutton.setIconSize(QtCore.QSize(30, 30))
        self.previousbutton.setAutoDefault(False)
        self.previousbutton.setDefault(False)
        self.previousbutton.setFlat(True)
        self.previousbutton.setObjectName(_fromUtf8("previousbutton"))
        self.horizontalLayout.addWidget(self.previousbutton)
        self.playbutton = QtGui.QPushButton(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playbutton.sizePolicy().hasHeightForWidth())
        self.playbutton.setSizePolicy(sizePolicy)
        self.playbutton.setText(_fromUtf8(""))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/play.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.playbutton.setIcon(icon1)
        self.playbutton.setIconSize(QtCore.QSize(30, 30))
        self.playbutton.setAutoDefault(False)
        self.playbutton.setFlat(True)
        self.playbutton.setObjectName(_fromUtf8("playbutton"))
        self.horizontalLayout.addWidget(self.playbutton)
        self.pausebutton = QtGui.QPushButton(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pausebutton.sizePolicy().hasHeightForWidth())
        self.pausebutton.setSizePolicy(sizePolicy)
        self.pausebutton.setText(_fromUtf8(""))
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/pause.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pausebutton.setIcon(icon2)
        self.pausebutton.setIconSize(QtCore.QSize(30, 30))
        self.pausebutton.setAutoDefault(False)
        self.pausebutton.setFlat(True)
        self.pausebutton.setObjectName(_fromUtf8("pausebutton"))
        self.horizontalLayout.addWidget(self.pausebutton)
        self.nextbutton = QtGui.QPushButton(music)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nextbutton.sizePolicy().hasHeightForWidth())
        self.nextbutton.setSizePolicy(sizePolicy)
        self.nextbutton.setText(_fromUtf8(""))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/next.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.nextbutton.setIcon(icon3)
        self.nextbutton.setIconSize(QtCore.QSize(30, 30))
        self.nextbutton.setAutoDefault(False)
        self.nextbutton.setFlat(True)
        self.nextbutton.setObjectName(_fromUtf8("nextbutton"))
        self.horizontalLayout.addWidget(self.nextbutton)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(music)
        QtCore.QMetaObject.connectSlotsByName(music)

    def retranslateUi(self, music):
        music.setWindowTitle(_translate("music", "Music Player", None))
        self.label_3.setText(_translate("music", "Volume", None))
        self.titel.setText(_translate("music", "TextLabel", None))
        self.interpreter.setText(_translate("music", "TextLabel", None))
        self.album.setText(_translate("music", "TextLabel", None))
        self.label_4.setText(_translate("music", "Rating", None))
        self.progress.setFormat(_translate("music", "%p", None))
        self.time.setText(_translate("music", "00:00", None))
        self.length.setText(_translate("music", "11:11", None))

from myProgressbar import MyProgressbar
import resource_rc

if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    music = QtGui.QDialog()
    ui = Ui_music()
    ui.setupUi(music)
    music.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/GUI.ui'
#
# Created: Thu Jul  2 15:57:03 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setWindowModality(QtCore.Qt.NonModal)
        MainWindow.resize(898, 720)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.horizontalLayout_6 = QtGui.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.frame = QtGui.QFrame(self.centralwidget)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName(_fromUtf8("frame"))
        self.gridLayout_4 = QtGui.QGridLayout(self.frame)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.verticalLayout_4 = QtGui.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_3 = QtGui.QLabel(self.frame)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout.addWidget(self.label_3)
        self.lineEditTitle = QtGui.QLineEdit(self.frame)
        self.lineEditTitle.setObjectName(_fromUtf8("lineEditTitle"))
        self.verticalLayout.addWidget(self.lineEditTitle)
        self.verticalLayout_4.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtGui.QVBoxLayout()
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.label_2 = QtGui.QLabel(self.frame)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout_2.addWidget(self.label_2)
        self.lineEditAlbum = QtGui.QLineEdit(self.frame)
        self.lineEditAlbum.setObjectName(_fromUtf8("lineEditAlbum"))
        self.verticalLayout_2.addWidget(self.lineEditAlbum)
        self.verticalLayout_4.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtGui.QVBoxLayout()
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.label = QtGui.QLabel(self.frame)
        self.label.setObjectName(_fromUtf8("label"))
        self.verticalLayout_3.addWidget(self.label)
        self.lineEditInterpreter = QtGui.QLineEdit(self.frame)
        self.lineEditInterpreter.setObjectName(_fromUtf8("lineEditInterpreter"))
        self.verticalLayout_3.addWidget(self.lineEditInterpreter)
        self.verticalLayout_4.addLayout(self.verticalLayout_3)
        self.verticalLayout_9 = QtGui.QVBoxLayout()
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.label_5 = QtGui.QLabel(self.frame)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout_9.addWidget(self.label_5)
        self.lineEditComment = QtGui.QLineEdit(self.frame)
        self.lineEditComment.setObjectName(_fromUtf8("lineEditComment"))
        self.verticalLayout_9.addWidget(self.lineEditComment)
        self.verticalLayout_4.addLayout(self.verticalLayout_9)
        self.verticalLayout_5 = QtGui.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.label_4 = QtGui.QLabel(self.frame)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_5.addWidget(self.label_4)
        self.spinBoxRating = QtGui.QSpinBox(self.frame)
        self.spinBoxRating.setMinimum(1)
        self.spinBoxRating.setMaximum(20)
        self.spinBoxRating.setObjectName(_fromUtf8("spinBoxRating"))
        self.verticalLayout_5.addWidget(self.spinBoxRating)
        self.verticalLayout_4.addLayout(self.verticalLayout_5)
        self.widget_2 = QtGui.QWidget(self.frame)
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setMargin(0)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.csCheckBox = QtGui.QCheckBox(self.widget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.csCheckBox.sizePolicy().hasHeightForWidth())
        self.csCheckBox.setSizePolicy(sizePolicy)
        self.csCheckBox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.csCheckBox.setAutoFillBackground(False)
        self.csCheckBox.setTristate(False)
        self.csCheckBox.setObjectName(_fromUtf8("csCheckBox"))
        self.horizontalLayout_2.addWidget(self.csCheckBox)
        self.verticalLayout_4.addWidget(self.widget_2)
        self.genreButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.genreButton.sizePolicy().hasHeightForWidth())
        self.genreButton.setSizePolicy(sizePolicy)
        self.genreButton.setObjectName(_fromUtf8("genreButton"))
        self.verticalLayout_4.addWidget(self.genreButton)
        self.horizontalLayout_7 = QtGui.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.filterResetButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterResetButton.sizePolicy().hasHeightForWidth())
        self.filterResetButton.setSizePolicy(sizePolicy)
        self.filterResetButton.setObjectName(_fromUtf8("filterResetButton"))
        self.horizontalLayout_7.addWidget(self.filterResetButton)
        self.saveButton = QtGui.QPushButton(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saveButton.sizePolicy().hasHeightForWidth())
        self.saveButton.setSizePolicy(sizePolicy)
        self.saveButton.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.saveButton.setObjectName(_fromUtf8("saveButton"))
        self.horizontalLayout_7.addWidget(self.saveButton)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.widget = QtGui.QWidget(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget.sizePolicy().hasHeightForWidth())
        self.widget.setSizePolicy(sizePolicy)
        self.widget.setObjectName(_fromUtf8("widget"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.widget)
        self.horizontalLayout.setMargin(0)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.verticalLayout_4.addWidget(self.widget)
        self.frame_3 = QtGui.QFrame(self.frame)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_3.setObjectName(_fromUtf8("frame_3"))
        self.verticalLayout_7 = QtGui.QVBoxLayout(self.frame_3)
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.tabWidget = QtGui.QTabWidget(self.frame_3)
        self.tabWidget.setTabPosition(QtGui.QTabWidget.North)
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.genretab = QtGui.QWidget()
        self.genretab.setObjectName(_fromUtf8("genretab"))
        self.gridLayout_5 = QtGui.QGridLayout(self.genretab)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.scrollGenre = QtGui.QScrollArea(self.genretab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollGenre.sizePolicy().hasHeightForWidth())
        self.scrollGenre.setSizePolicy(sizePolicy)
        self.scrollGenre.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollGenre.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollGenre.setWidgetResizable(False)
        self.scrollGenre.setObjectName(_fromUtf8("scrollGenre"))
        self.genreWidget = QtGui.QWidget()
        self.genreWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.genreWidget.sizePolicy().hasHeightForWidth())
        self.genreWidget.setSizePolicy(sizePolicy)
        self.genreWidget.setObjectName(_fromUtf8("genreWidget"))
        self.gridLayout_2 = QtGui.QGridLayout(self.genreWidget)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.genreLayout = QtGui.QFormLayout()
        self.genreLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.genreLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.genreLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.genreLayout.setObjectName(_fromUtf8("genreLayout"))
        self.gridLayout_2.addLayout(self.genreLayout, 0, 0, 1, 1)
        self.scrollGenre.setWidget(self.genreWidget)
        self.gridLayout_5.addWidget(self.scrollGenre, 0, 0, 1, 1)
        self.tabWidget.addTab(self.genretab, _fromUtf8(""))
        self.albumtab = QtGui.QWidget()
        self.albumtab.setObjectName(_fromUtf8("albumtab"))
        self.gridLayout_7 = QtGui.QGridLayout(self.albumtab)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.scrollAlbum = QtGui.QScrollArea(self.albumtab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollAlbum.sizePolicy().hasHeightForWidth())
        self.scrollAlbum.setSizePolicy(sizePolicy)
        self.scrollAlbum.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollAlbum.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollAlbum.setWidgetResizable(False)
        self.scrollAlbum.setObjectName(_fromUtf8("scrollAlbum"))
        self.albumWidget = QtGui.QWidget()
        self.albumWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.albumWidget.sizePolicy().hasHeightForWidth())
        self.albumWidget.setSizePolicy(sizePolicy)
        self.albumWidget.setObjectName(_fromUtf8("albumWidget"))
        self.gridLayout_6 = QtGui.QGridLayout(self.albumWidget)
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.albumLayout = QtGui.QFormLayout()
        self.albumLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.albumLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.albumLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.albumLayout.setObjectName(_fromUtf8("albumLayout"))
        self.gridLayout_6.addLayout(self.albumLayout, 0, 0, 1, 1)
        self.scrollAlbum.setWidget(self.albumWidget)
        self.gridLayout_7.addWidget(self.scrollAlbum, 0, 0, 1, 1)
        self.tabWidget.addTab(self.albumtab, _fromUtf8(""))
        self.interpretertab = QtGui.QWidget()
        self.interpretertab.setObjectName(_fromUtf8("interpretertab"))
        self.gridLayout_9 = QtGui.QGridLayout(self.interpretertab)
        self.gridLayout_9.setObjectName(_fromUtf8("gridLayout_9"))
        self.scrollInterpreter = QtGui.QScrollArea(self.interpretertab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollInterpreter.sizePolicy().hasHeightForWidth())
        self.scrollInterpreter.setSizePolicy(sizePolicy)
        self.scrollInterpreter.setMinimumSize(QtCore.QSize(200, 0))
        self.scrollInterpreter.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.scrollInterpreter.setWidgetResizable(False)
        self.scrollInterpreter.setObjectName(_fromUtf8("scrollInterpreter"))
        self.interpreterWidget = QtGui.QWidget()
        self.interpreterWidget.setGeometry(QtCore.QRect(0, 0, 172, 460))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.interpreterWidget.sizePolicy().hasHeightForWidth())
        self.interpreterWidget.setSizePolicy(sizePolicy)
        self.interpreterWidget.setObjectName(_fromUtf8("interpreterWidget"))
        self.gridLayout_8 = QtGui.QGridLayout(self.interpreterWidget)
        self.gridLayout_8.setObjectName(_fromUtf8("gridLayout_8"))
        self.interpreterLayout = QtGui.QFormLayout()
        self.interpreterLayout.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.interpreterLayout.setRowWrapPolicy(QtGui.QFormLayout.DontWrapRows)
        self.interpreterLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.interpreterLayout.setObjectName(_fromUtf8("interpreterLayout"))
        self.gridLayout_8.addLayout(self.interpreterLayout, 0, 0, 1, 1)
        self.scrollInterpreter.setWidget(self.interpreterWidget)
        self.gridLayout_9.addWidget(self.scrollInterpreter, 0, 0, 1, 1)
        self.tabWidget.addTab(self.interpretertab, _fromUtf8(""))
        self.verticalLayout_7.addWidget(self.tabWidget)
        self.verticalLayout_4.addWidget(self.frame_3)
        self.gridLayout_4.addLayout(self.verticalLayout_4, 1, 0, 1, 1)
        self.label_7 = QtGui.QLabel(self.frame)
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setMargin(5)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.gridLayout_4.addWidget(self.label_7, 0, 0, 1, 1)
        self.horizontalLayout_6.addWidget(self.frame)
        self.verticalLayout_10 = QtGui.QVBoxLayout()
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.frame_2 = QtGui.QFrame(self.centralwidget)
        self.frame_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_2.setObjectName(_fromUtf8("frame_2"))
        self.verticalLayout_13 = QtGui.QVBoxLayout(self.frame_2)
        self.verticalLayout_13.setObjectName(_fromUtf8("verticalLayout_13"))
        self.label_8 = QtGui.QLabel(self.frame_2)
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setMargin(5)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.verticalLayout_13.addWidget(self.label_8)
        self.tableWidget = MyDragTable(self.frame_2)
        self.tableWidget.setFrameShape(QtGui.QFrame.NoFrame)
        self.tableWidget.setFrameShadow(QtGui.QFrame.Raised)
        self.tableWidget.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.tableWidget.setAutoScroll(False)
        self.tableWidget.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.tableWidget.setTabKeyNavigation(False)
        self.tableWidget.setProperty("showDropIndicator", False)
        self.tableWidget.setDragEnabled(True)
        self.tableWidget.setDragDropOverwriteMode(False)
        self.tableWidget.setDragDropMode(QtGui.QAbstractItemView.DragOnly)
        self.tableWidget.setAlternatingRowColors(True)
        self.tableWidget.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
        self.tableWidget.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.tableWidget.setTextElideMode(QtCore.Qt.ElideNone)
        self.tableWidget.setShowGrid(True)
        self.tableWidget.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget.setWordWrap(False)
        self.tableWidget.setCornerButtonEnabled(False)
        self.tableWidget.setObjectName(_fromUtf8("tableWidget"))
        self.tableWidget.setColumnCount(8)
        self.tableWidget.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(4, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(5, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(6, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(7, item)
        self.tableWidget.horizontalHeader().setVisible(True)
        self.tableWidget.horizontalHeader().setCascadingSectionResizes(False)
        self.tableWidget.horizontalHeader().setHighlightSections(True)
        self.tableWidget.verticalHeader().setVisible(False)
        self.tableWidget.verticalHeader().setHighlightSections(False)
        self.verticalLayout_13.addWidget(self.tableWidget)
        self.musicframe = QtGui.QWidget(self.frame_2)
        self.musicframe.setObjectName(_fromUtf8("musicframe"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.musicframe)
        self.verticalLayout_6.setMargin(0)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.musicdock = QtGui.QDockWidget(self.musicframe)
        self.musicdock.setFloating(False)
        self.musicdock.setFeatures(QtGui.QDockWidget.AllDockWidgetFeatures)
        self.musicdock.setAllowedAreas(QtCore.Qt.NoDockWidgetArea)
        self.musicdock.setObjectName(_fromUtf8("musicdock"))
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.musiclayout = QtGui.QVBoxLayout()
        self.musiclayout.setObjectName(_fromUtf8("musiclayout"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.timebar = MyProgressbar(self.dockWidgetContents)
        self.timebar.setMinimumSize(QtCore.QSize(0, 10))
        self.timebar.setMaximumSize(QtCore.QSize(16777215, 10))
        self.timebar.setProperty("value", 0)
        self.timebar.setTextVisible(False)
        self.timebar.setFormat(_fromUtf8(""))
        self.timebar.setObjectName(_fromUtf8("timebar"))
        self.horizontalLayout_3.addWidget(self.timebar)
        self.time = QtGui.QLabel(self.dockWidgetContents)
        self.time.setObjectName(_fromUtf8("time"))
        self.horizontalLayout_3.addWidget(self.time)
        self.length = QtGui.QLabel(self.dockWidgetContents)
        self.length.setObjectName(_fromUtf8("length"))
        self.horizontalLayout_3.addWidget(self.length)
        self.musiclayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.previousbutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.previousbutton.sizePolicy().hasHeightForWidth())
        self.previousbutton.setSizePolicy(sizePolicy)
        self.previousbutton.setText(_fromUtf8(""))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/previous.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.previousbutton.setIcon(icon)
        self.previousbutton.setIconSize(QtCore.QSize(30, 30))
        self.previousbutton.setFlat(True)
        self.previousbutton.setObjectName(_fromUtf8("previousbutton"))
        self.horizontalLayout_4.addWidget(self.previousbutton)
        self.playbutton_2 = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playbutton_2.sizePolicy().hasHeightForWidth())
        self.playbutton_2.setSizePolicy(sizePolicy)
        self.playbutton_2.setText(_fromUtf8(""))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/play.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.playbutton_2.setIcon(icon1)
        self.playbutton_2.setIconSize(QtCore.QSize(30, 30))
        self.playbutton_2.setFlat(True)
        self.playbutton_2.setObjectName(_fromUtf8("playbutton_2"))
        self.horizontalLayout_4.addWidget(self.playbutton_2)
        self.pausebutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pausebutton.sizePolicy().hasHeightForWidth())
        self.pausebutton.setSizePolicy(sizePolicy)
        self.pausebutton.setText(_fromUtf8(""))
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/pause.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pausebutton.setIcon(icon2)
        self.pausebutton.setIconSize(QtCore.QSize(30, 30))
        self.pausebutton.setFlat(True)
        self.pausebutton.setObjectName(_fromUtf8("pausebutton"))
        self.horizontalLayout_4.addWidget(self.pausebutton)
        self.nextbutton = QtGui.QPushButton(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nextbutton.sizePolicy().hasHeightForWidth())
        self.nextbutton.setSizePolicy(sizePolicy)
        self.nextbutton.setText(_fromUtf8(""))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/music_layout/resources/next.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.nextbutton.setIcon(icon3)
        self.nextbutton.setIconSize(QtCore.QSize(30, 30))
        self.nextbutton.setFlat(True)
        self.nextbutton.setObjectName(_fromUtf8("nextbutton"))
        self.horizontalLayout_4.addWidget(self.nextbutton)
        self.verticalLayout_8 = QtGui.QVBoxLayout()
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.volume = QtGui.QLabel(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.volume.sizePolicy().hasHeightForWidth())
        self.volume.setSizePolicy(sizePolicy)
        self.volume.setObjectName(_fromUtf8("volume"))
        self.verticalLayout_8.addWidget(self.volume)
        self.soundSlider = QtGui.QSlider(self.dockWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.soundSlider.sizePolicy().hasHeightForWidth())
        self.soundSlider.setSizePolicy(sizePolicy)
        self.soundSlider.setMaximum(10)
        self.soundSlider.setProperty("value", 1)
        self.soundSlider.setOrientation(QtCore.Qt.Horizontal)
        self.soundSlider.setObjectName(_fromUtf8("soundSlider"))
        self.verticalLayout_8.addWidget(self.soundSlider)
        self.horizontalLayout_4.addLayout(self.verticalLayout_8)
        self.musiclayout.addLayout(self.horizontalLayout_4)
        self.gridLayout.addLayout(self.musiclayout, 0, 0, 1, 1)
        self.musicdock.setWidget(self.dockWidgetContents)
        self.verticalLayout_6.addWidget(self.musicdock)
        self.verticalLayout_13.addWidget(self.musicframe)
        self.verticalLayout_13.setStretch(0, 1)
        self.verticalLayout_13.setStretch(1, 100)
        self.verticalLayout_10.addWidget(self.frame_2)
        self.horizontalLayout_6.addLayout(self.verticalLayout_10)
        self.playlistTab = QtGui.QTabWidget(self.centralwidget)
        self.playlistTab.setObjectName(_fromUtf8("playlistTab"))
        self.playlistsearch = QtGui.QWidget()
        self.playlistsearch.setObjectName(_fromUtf8("playlistsearch"))
        self.gridLayout_10 = QtGui.QGridLayout(self.playlistsearch)
        self.gridLayout_10.setObjectName(_fromUtf8("gridLayout_10"))
        self.playlistTreeView = MyTreeView(self.playlistsearch)
        self.playlistTreeView.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.playlistTreeView.setProperty("showDropIndicator", False)
        self.playlistTreeView.setSelectionBehavior(QtGui.QAbstractItemView.SelectItems)
        self.playlistTreeView.setObjectName(_fromUtf8("playlistTreeView"))
        self.gridLayout_10.addWidget(self.playlistTreeView, 3, 0, 1, 1)
        self.horizontalLayout_8 = QtGui.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.playlistFolderLineEdit = QtGui.QLineEdit(self.playlistsearch)
        self.playlistFolderLineEdit.setText(_fromUtf8(""))
        self.playlistFolderLineEdit.setObjectName(_fromUtf8("playlistFolderLineEdit"))
        self.horizontalLayout_8.addWidget(self.playlistFolderLineEdit)
        self.playlistCreateFolderButton = QtGui.QPushButton(self.playlistsearch)
        self.playlistCreateFolderButton.setObjectName(_fromUtf8("playlistCreateFolderButton"))
        self.horizontalLayout_8.addWidget(self.playlistCreateFolderButton)
        self.gridLayout_10.addLayout(self.horizontalLayout_8, 0, 0, 1, 1)
        self.horizontalLayout_9 = QtGui.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.playlistSearchLineEdit = QtGui.QComboBox(self.playlistsearch)
        self.playlistSearchLineEdit.setEditable(True)
        self.playlistSearchLineEdit.setInsertPolicy(QtGui.QComboBox.InsertAfterCurrent)
        self.playlistSearchLineEdit.setDuplicatesEnabled(True)
        self.playlistSearchLineEdit.setFrame(True)
        self.playlistSearchLineEdit.setObjectName(_fromUtf8("playlistSearchLineEdit"))
        self.horizontalLayout_9.addWidget(self.playlistSearchLineEdit)
        self.playlistSearchButton = QtGui.QPushButton(self.playlistsearch)
        self.playlistSearchButton.setObjectName(_fromUtf8("playlistSearchButton"))
        self.horizontalLayout_9.addWidget(self.playlistSearchButton)
        self.horizontalLayout_9.setStretch(0, 2)
        self.horizontalLayout_9.setStretch(1, 1)
        self.gridLayout_10.addLayout(self.horizontalLayout_9, 4, 0, 1, 1)
        self.playlistTab.addTab(self.playlistsearch, _fromUtf8(""))
        self.playlistInfo = QtGui.QWidget()
        self.playlistInfo.setObjectName(_fromUtf8("playlistInfo"))
        self.verticalLayout_11 = QtGui.QVBoxLayout(self.playlistInfo)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.playlistLineEdit = QtGui.QLineEdit(self.playlistInfo)
        self.playlistLineEdit.setMouseTracking(False)
        self.playlistLineEdit.setAcceptDrops(False)
        self.playlistLineEdit.setFrame(False)
        self.playlistLineEdit.setEchoMode(QtGui.QLineEdit.Normal)
        self.playlistLineEdit.setAlignment(QtCore.Qt.AlignCenter)
        self.playlistLineEdit.setObjectName(_fromUtf8("playlistLineEdit"))
        self.verticalLayout_11.addWidget(self.playlistLineEdit)
        self.playlistWidget = MyDropTable(self.playlistInfo)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playlistWidget.sizePolicy().hasHeightForWidth())
        self.playlistWidget.setSizePolicy(sizePolicy)
        self.playlistWidget.setFrameShape(QtGui.QFrame.NoFrame)
        self.playlistWidget.setFrameShadow(QtGui.QFrame.Plain)
        self.playlistWidget.setLineWidth(0)
        self.playlistWidget.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.playlistWidget.setTabKeyNavigation(False)
        self.playlistWidget.setProperty("showDropIndicator", False)
        self.playlistWidget.setDragDropOverwriteMode(False)
        self.playlistWidget.setDragDropMode(QtGui.QAbstractItemView.DropOnly)
        self.playlistWidget.setDefaultDropAction(QtCore.Qt.CopyAction)
        self.playlistWidget.setAlternatingRowColors(True)
        self.playlistWidget.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.playlistWidget.setTextElideMode(QtCore.Qt.ElideNone)
        self.playlistWidget.setGridStyle(QtCore.Qt.NoPen)
        self.playlistWidget.setWordWrap(False)
        self.playlistWidget.setCornerButtonEnabled(False)
        self.playlistWidget.setObjectName(_fromUtf8("playlistWidget"))
        self.playlistWidget.setColumnCount(3)
        self.playlistWidget.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.playlistWidget.setHorizontalHeaderItem(2, item)
        self.playlistWidget.horizontalHeader().setHighlightSections(False)
        self.playlistWidget.verticalHeader().setVisible(False)
        self.playlistWidget.verticalHeader().setDefaultSectionSize(20)
        self.playlistWidget.verticalHeader().setHighlightSections(False)
        self.verticalLayout_11.addWidget(self.playlistWidget)
        self.playlistSaveButton = QtGui.QPushButton(self.playlistInfo)
        self.playlistSaveButton.setObjectName(_fromUtf8("playlistSaveButton"))
        self.verticalLayout_11.addWidget(self.playlistSaveButton)
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.playallbutton = QtGui.QPushButton(self.playlistInfo)
        self.playallbutton.setObjectName(_fromUtf8("playallbutton"))
        self.horizontalLayout_5.addWidget(self.playallbutton)
        self.resetallbutton = QtGui.QPushButton(self.playlistInfo)
        self.resetallbutton.setObjectName(_fromUtf8("resetallbutton"))
        self.horizontalLayout_5.addWidget(self.resetallbutton)
        self.verticalLayout_11.addLayout(self.horizontalLayout_5)
        self.playbutton = QtGui.QPushButton(self.playlistInfo)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.playbutton.sizePolicy().hasHeightForWidth())
        self.playbutton.setSizePolicy(sizePolicy)
        self.playbutton.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.playbutton.setObjectName(_fromUtf8("playbutton"))
        self.verticalLayout_11.addWidget(self.playbutton)
        self.playlistTab.addTab(self.playlistInfo, _fromUtf8(""))
        self.horizontalLayout_6.addWidget(self.playlistTab)
        self.horizontalLayout_6.setStretch(0, 1)
        self.horizontalLayout_6.setStretch(1, 5)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 898, 21))
        self.menuBar.setObjectName(_fromUtf8("menuBar"))
        self.menuDatei = QtGui.QMenu(self.menuBar)
        self.menuDatei.setObjectName(_fromUtf8("menuDatei"))
        self.menuInfo = QtGui.QMenu(self.menuBar)
        self.menuInfo.setObjectName(_fromUtf8("menuInfo"))
        self.menuSong = QtGui.QMenu(self.menuBar)
        self.menuSong.setObjectName(_fromUtf8("menuSong"))
        MainWindow.setMenuBar(self.menuBar)
        self.actionVerzeichnis_wechseln = QtGui.QAction(MainWindow)
        self.actionVerzeichnis_wechseln.setObjectName(_fromUtf8("actionVerzeichnis_wechseln"))
        self.actionBeenden = QtGui.QAction(MainWindow)
        self.actionBeenden.setObjectName(_fromUtf8("actionBeenden"))
        self.actionInfo = QtGui.QAction(MainWindow)
        self.actionInfo.setObjectName(_fromUtf8("actionInfo"))
        self.actionRefresh = QtGui.QAction(MainWindow)
        self.actionRefresh.setObjectName(_fromUtf8("actionRefresh"))
        self.actionEdit = QtGui.QAction(MainWindow)
        self.actionEdit.setObjectName(_fromUtf8("actionEdit"))
        self.menuDatei.addAction(self.actionRefresh)
        self.menuDatei.addAction(self.actionVerzeichnis_wechseln)
        self.menuDatei.addSeparator()
        self.menuDatei.addAction(self.actionBeenden)
        self.menuInfo.addAction(self.actionInfo)
        self.menuSong.addAction(self.actionEdit)
        self.menuBar.addAction(self.menuDatei.menuAction())
        self.menuBar.addAction(self.menuSong.menuAction())
        self.menuBar.addAction(self.menuInfo.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.playlistTab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "Music Manager", None))
        self.label_3.setText(_translate("MainWindow", "Title", None))
        self.label_2.setText(_translate("MainWindow", "Album", None))
        self.label.setText(_translate("MainWindow", "Interpreter", None))
        self.label_5.setText(_translate("MainWindow", "Comment", None))
        self.label_4.setText(_translate("MainWindow", "Rating", None))
        self.csCheckBox.setText(_translate("MainWindow", "CS", None))
        self.genreButton.setText(_translate("MainWindow", "Edit Genres", None))
        self.filterResetButton.setText(_translate("MainWindow", "Filter Reset", None))
        self.saveButton.setText(_translate("MainWindow", "Save", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.genretab), _translate("MainWindow", "Genres", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.albumtab), _translate("MainWindow", "Album", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.interpretertab), _translate("MainWindow", "Interpret", None))
        self.label_7.setText(_translate("MainWindow", "Edit", None))
        self.label_8.setText(_translate("MainWindow", "Current Directory", None))
        self.tableWidget.setSortingEnabled(True)
        item = self.tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "hidden", None))
        item = self.tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Name", None))
        item = self.tableWidget.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Title", None))
        item = self.tableWidget.horizontalHeaderItem(3)
        item.setText(_translate("MainWindow", "Album", None))
        item = self.tableWidget.horizontalHeaderItem(4)
        item.setText(_translate("MainWindow", "Interpreter", None))
        item = self.tableWidget.horizontalHeaderItem(5)
        item.setText(_translate("MainWindow", "Genres", None))
        item = self.tableWidget.horizontalHeaderItem(6)
        item.setText(_translate("MainWindow", "Times Played", None))
        item = self.tableWidget.horizontalHeaderItem(7)
        item.setText(_translate("MainWindow", "Rating", None))
        self.musicdock.setWindowTitle(_translate("MainWindow", "Music Player", None))
        self.time.setText(_translate("MainWindow", "00:00", None))
        self.length.setText(_translate("MainWindow", "00:00", None))
        self.volume.setText(_translate("MainWindow", "Volume", None))
        self.playlistFolderLineEdit.setPlaceholderText(_translate("MainWindow", "New subfolder name", None))
        self.playlistCreateFolderButton.setText(_translate("MainWindow", "Create Folder", None))
        self.playlistSearchButton.setText(_translate("MainWindow", "search", None))
        self.playlistTab.setTabText(self.playlistTab.indexOf(self.playlistsearch), _translate("MainWindow", "Playlists", None))
        self.playlistLineEdit.setPlaceholderText(_translate("MainWindow", "Please Insert a title", None))
        item = self.playlistWidget.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "path(HIDDEN)", None))
        item = self.playlistWidget.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Title", None))
        item = self.playlistWidget.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Length", None))
        self.playlistSaveButton.setText(_translate("MainWindow", "Save Playlist", None))
        self.playallbutton.setText(_translate("MainWindow", "Play Playlist", None))
        self.resetallbutton.setText(_translate("MainWindow", "Shuffle", None))
        self.playbutton.setText(_translate("MainWindow", "Playlist Random Play", None))
        self.playlistTab.setTabText(self.playlistTab.indexOf(self.playlistInfo), _translate("MainWindow", "Aktive Playlist", None))
        self.menuDatei.setTitle(_translate("MainWindow", "Data", None))
        self.menuInfo.setTitle(_translate("MainWindow", "Info", None))
        self.menuSong.setTitle(_translate("MainWindow", "Song", None))
        self.actionVerzeichnis_wechseln.setText(_translate("MainWindow", "Change Directory", None))
        self.actionBeenden.setText(_translate("MainWindow", "Exit", None))
        self.actionInfo.setText(_translate("MainWindow", "Info", None))
        self.actionRefresh.setText(_translate("MainWindow", "Refresh", None))
        self.actionEdit.setText(_translate("MainWindow", "Edit", None))

from myDropTable import MyDropTable
from myProgressbar import MyProgressbar
from myDragTable import MyDragTable
from mytreeview import MyTreeView
import resource_rc

if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    MainWindow = QtGui.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/genre.ui'
#
# Created: Wed Jul  1 11:27:57 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_genre(object):
    def setupUi(self, genre):
        genre.setObjectName(_fromUtf8("genre"))
        genre.setWindowModality(QtCore.Qt.ApplicationModal)
        genre.resize(265, 121)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(genre.sizePolicy().hasHeightForWidth())
        genre.setSizePolicy(sizePolicy)
        genre.setMinimumSize(QtCore.QSize(265, 121))
        genre.setMaximumSize(QtCore.QSize(265, 121))
        self.verticalLayout_2 = QtGui.QVBoxLayout(genre)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.verticalLayout = QtGui.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.gridLayout_2 = QtGui.QGridLayout()
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.comboboxdel = QtGui.QComboBox(genre)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboboxdel.sizePolicy().hasHeightForWidth())
        self.comboboxdel.setSizePolicy(sizePolicy)
        self.comboboxdel.setObjectName(_fromUtf8("comboboxdel"))
        self.gridLayout_2.addWidget(self.comboboxdel, 0, 0, 1, 1)
        self.buttondel = QtGui.QPushButton(genre)
        self.buttondel.setAutoDefault(False)
        self.buttondel.setObjectName(_fromUtf8("buttondel"))
        self.gridLayout_2.addWidget(self.buttondel, 0, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_2)
        self.gridLayout = QtGui.QGridLayout()
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.comboboxadd = QtGui.QComboBox(genre)
        self.comboboxadd.setEditable(True)
        self.comboboxadd.setObjectName(_fromUtf8("comboboxadd"))
        self.gridLayout.addWidget(self.comboboxadd, 0, 0, 1, 1)
        self.buttonadd = QtGui.QPushButton(genre)
        self.buttonadd.setObjectName(_fromUtf8("buttonadd"))
        self.gridLayout.addWidget(self.buttonadd, 0, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.buttonfinish = QtGui.QPushButton(genre)
        self.buttonfinish.setAutoDefault(False)
        self.buttonfinish.setObjectName(_fromUtf8("buttonfinish"))
        self.verticalLayout.addWidget(self.buttonfinish)
        self.verticalLayout_2.addLayout(self.verticalLayout)

        self.retranslateUi(genre)
        QtCore.QMetaObject.connectSlotsByName(genre)

    def retranslateUi(self, genre):
        genre.setWindowTitle(_translate("genre", "Genres einfügen", None))
        self.buttondel.setText(_translate("genre", "Löschen", None))
        self.buttonadd.setText(_translate("genre", "Hinzufügen", None))
        self.buttonfinish.setText(_translate("genre", "fertig", None))


if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    genre = QtGui.QDialog()
    ui = Ui_genre()
    ui.setupUi(genre)
    genre.show()
    sys.exit(app.exec_())




from PyQt4.QtGui import *
from PyQt4.QtCore import *

class MyDragTable(QTableWidget):
    activate = pyqtSignal(QTableWidgetItem)
    returnpressed = pyqtSignal()
    
    def __init__(self, parent=None):
        QTableWidget.__init__(self)
        
    def itemClicked(self, item):
        self.activate.emit(item)
        
    def keyPressEvent(self, e):
        if e.type() == QEvent.KeyPress:
                if e.key() == Qt.Key_Return:
                    self.returnpressed.emit()
        QTableWidget.keyPressEvent(self, e)

    def mimeTypes(self):
        return ('application/x-songlistdata')

    def mimeData(self, list):
        bytearray = QByteArray()
        for item in list:
            if item.column() == 1:
                bytearray.append(self.item(item.row(), 0).text() + '\\')
                
        bytearray.chop(1)
        
        mimeData = QMimeData()
        mimeData.setData('application/x-songlistdata', bytearray)
        return mimeData



# -*- coding: utf-8 -*-

"""
Module implementing SearchDialog.
"""
from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_search import Ui_Dialog

class SearchDialog(QDialog, Ui_Dialog):
    """
    Dient zur einfach suche des Ordners in welchem die Lieder sich befinden.
    """
    def __init__(self, parent = None):
        """
        Constructor
        """
        QDialog.__init__(self, parent)
        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
        self.setupUi(self)
        # WEGEN TESTZWECKEN DAMIT ES EINFACHER IST
        self.lineEditPath.setText('/home/cch/Documents/python/music manager/files')
        self.currentDir = None
        self.files = []
        self.PATH = None
    
    def get_path(self):
        return self.PATH
    
    def get_currentdir(self):
        return self.currentDir
    
    def get_files(self):
        return self.files
    
    @pyqtSignature("")
    def on_buttonBox_accepted(self):
        """
        Slot documentation goes here.
        """
        self.PATH = str(self.lineEditPath.text())
        self.currentDir = QDir(self.PATH)
  
        self.files = self.currentDir.entryList(QStringList("*"), QDir.Files | QDir.NoSymLinks)
        self.accept()
    
    @pyqtSignature("")
    def on_directoryPath_clicked(self):
        """
        Slot documentation goes here.
        """
        self.lineEditPath.setText(QFileDialog.getExistingDirectory())

    @pyqtSignature("")
    def on_buttonBox_rejected(self):
        self.reject()



from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_musicplayer import Ui_music

class MusicPlayer(QDialog, Ui_music):
    playclicked = pyqtSignal()
    pauseclicked = pyqtSignal()
    nextclicked = pyqtSignal()
    previousclicked = pyqtSignal()
    soundsliderchanged = pyqtSignal(int)
    ratingchanged = pyqtSignal(int)
    timechanged = pyqtSignal(float)
    release = pyqtSignal()
    playerhidden = pyqtSignal(int)
    
    def __init__(self, parent=None):
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
        self.titeli = -12
        self.albumi = -12
        self.interpreteri = -12
        
        self.spinBoxRating.setReadOnly(True)
        self.spinBoxRating.setReadOnly(False)
        
        self.setFixedSize(self.size())
        
        self.progress.releasePlay.connect(self.releasePlay)
        self.progress.progressMovement.connect(self.progressMovement)
        
        self.titelscroll = QTimer(parent)
        self.titelscroll.timeout.connect(self.titeltimeout)
        self.titelscroll.start(350)
        
        self.albumscroll = QTimer(parent)
        self.albumscroll.timeout.connect(self.albumtimeout)
        self.albumscroll.start(350)
        
        self.interpreterscroll = QTimer(parent)
        self.interpreterscroll.timeout.connect(self.interpretertimeout)
        self.interpreterscroll.start(350)

    def titeltimeout(self):
        if self.scrolltitel.horizontalScrollBar().value() < self.scrolltitel.horizontalScrollBar().maximum() and self.titeli >= 0:
            self.scrolltitel.horizontalScrollBar().setValue(self.scrolltitel.horizontalScrollBar().value()+10)
        elif self.titeli >= 4:
            self.scrolltitel.horizontalScrollBar().setValue(0)
            self.titeli = -8
        else:
            self.titeli += 1

        
    def albumtimeout(self):
        if self.scrollalbum.horizontalScrollBar().value() < self.scrollalbum.horizontalScrollBar().maximum() and self.albumi >= 0:
            self.scrollalbum.horizontalScrollBar().setValue(self.scrollalbum.horizontalScrollBar().value()+10)
        elif self.albumi >= 4:
            self.scrollalbum.horizontalScrollBar().setValue(0)
            self.albumi = -8
        else:
            self.albumi += 1
        
    def interpretertimeout(self):
        if self.scrollinterpreter.horizontalScrollBar().value() < self.scrollinterpreter.horizontalScrollBar().maximum() and self.interpreteri >= 0:
            self.scrollinterpreter.horizontalScrollBar().setValue(self.scrollinterpreter.horizontalScrollBar().value()+10)
        elif self.interpreteri >= 4:
            self.scrollinterpreter.horizontalScrollBar().setValue(0)
            self.interpreteri = -8
        else:
            self.interpreteri += 1

    def set_songInfos(self, title, album, interpreter, rating, length, range):
        self.titel.setText(title)
        self.album.setText(album)
        self.interpreter.setText(interpreter)
        self.spinBoxRating.setValue(rating)
        self.progress.setRange(0, range)
        self.length.setText(length)

    def set_volume(self, volume):
        self.soundSlider.setValue(volume)

    def update_progress(self, time):
        self.progress.setValue(time*50)
        m, s = divmod(time, 60)
        self.time.setText("%02d:%02d" % (m, s))
    
    def releasePlay(self):
        self.release.emit()
        
    def progressMovement(self, percent):
        self.timechanged.emit(percent)
        
    def closeEvent(self, e):
        e.ignore()
        self.hide()
        self.playerhidden.emit(0)

    @pyqtSignature("")
    def on_dockbutton_clicked(self):
        """
        Slot documentation goes here.
        """
        self.hide()
        self.playerhidden.emit(1)

    def resizeEvent(self, e):
        self.resize(QResizeEvent.oldSize(e))

    @pyqtSignature("")
    def on_playbutton_clicked(self):
        """
        Slot documentation goes here.
        """
        self.playclicked.emit()
    
    @pyqtSignature("")
    def on_pausebutton_clicked(self):
        """
        Slot documentation goes here.
        """
        self.pauseclicked.emit()
    
    @pyqtSignature("")
    def on_previousbutton_clicked(self):
        """
        Slot documentation goes here.
        """
        self.previousclicked.emit()
    
    @pyqtSignature("")
    def on_nextbutton_clicked(self):
        """
        Slot documentation goes here.
        """
        self.nextclicked.emit()
    
    @pyqtSignature("int")
    def on_spinBoxRating_valueChanged(self, p0):
        """
        Slot documentation goes here.
        """
        self.ratingchanged.emit(p0)
    
    @pyqtSignature("int")
    def on_soundSlider_valueChanged(self, value):
        """
        Slot documentation goes here.
        """
        self.soundsliderchanged.emit(value)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/info.ui'
#
# Created: Thu Jul  2 16:19:55 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Info(object):
    def setupUi(self, Info):
        Info.setObjectName(_fromUtf8("Info"))
        Info.setWindowModality(QtCore.Qt.ApplicationModal)
        Info.resize(400, 200)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Info.sizePolicy().hasHeightForWidth())
        Info.setSizePolicy(sizePolicy)
        Info.setMinimumSize(QtCore.QSize(400, 200))
        Info.setMaximumSize(QtCore.QSize(600, 400))
        Info.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.verticalLayout = QtGui.QVBoxLayout(Info)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label = QtGui.QLabel(Info)
        self.label.setObjectName(_fromUtf8("label"))
        self.verticalLayout.addWidget(self.label)
        self.label_2 = QtGui.QLabel(Info)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout.addWidget(self.label_2)
        self.label_3 = QtGui.QLabel(Info)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout.addWidget(self.label_3)
        self.label_4 = QtGui.QLabel(Info)
        self.label_4.setWordWrap(True)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout.addWidget(self.label_4)
        self.buttonBox = QtGui.QDialogButtonBox(Info)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Close)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(Info)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), Info.reject)
        QtCore.QMetaObject.connectSlotsByName(Info)

    def retranslateUi(self, Info):
        Info.setWindowTitle(_translate("Info", "Info", None))
        self.label.setText(_translate("Info", "Musik Manager (Temporary)", None))
        self.label_2.setText(_translate("Info", "Author: Cédric Christen", None))
        self.label_3.setText(_translate("Info", "Version: 0.1", None))
        self.label_4.setText(_translate("Info", "Manage your music files with Music Manager and also use the music player to hear your songs from playlists with different types of randomness.", None))


if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    Info = QtGui.QDialog()
    ui = Ui_Info()
    ui.setupUi(Info)
    Info.show()
    sys.exit(app.exec_())




from PyQt4.QtGui import *
from PyQt4.QtCore import *

class MyProgressbar(QProgressBar):
    releasePlay = pyqtSignal()
    progressMovement = pyqtSignal(float)
    
    def __init__(self, parent=None):
        QProgressBar.__init__(self)
        
            
    def mousePressEvent(self, e):
        self.mouseMoveEvent(e)
            
    def mouseMoveEvent(self, e):
        if (e.buttons() & Qt.LeftButton) is not 0:
            if e.pos().x() < 0:
                self.x = 0
            elif e.pos().x() > self.width():
                self.x = self.width() / self.width()
            else:
                self.x = e.pos().x() / float(self.width())
                
            self.progressMovement.emit(self.x)
            
    def mouseReleaseEvent(self, e):
        self.releasePlay.emit()



# -*- coding: utf-8 -*-

"""
Module implementing Loading.
"""

from PyQt4.QtCore import *
from PyQt4.QtGui import *

from Ui_load import Ui_Load


class Loading(QDialog, Ui_Load):
    """
    Class documentation goes here.
    """
    def __init__(self, maximum, parent=None):
        """
        Constructor
        
        @param parent reference to the parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.progressBar.setMaximum(maximum)
        
    def set_loading(self, progress):
        self.progressBar.setValue(progress)



# -*- coding: utf-8 -*-

"""
Module implementing Info.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_info import Ui_Info


class Info(QDialog, Ui_Info):
    """
    Class documentation goes here.
    """
    def __init__(self, parent=None):
        """
        Constructor
        
        @param parent reference to the parent widget (QWidget)
        """
    
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
        



# -*- coding: utf-8 -*-
"""
Module implementing genre.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_genre import Ui_genre

class Genre(QDialog, Ui_genre):
    """
    Genre-Bearbeitung wird hier geregelt und auch per Dialog übersichtlich gestaltet.
    """
    def __init__(self, c, conn, path, parent = None):
        """
        Constructor
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        self.c = c
        self.conn = conn
        self.path = path
        self.comboboxadd.lineEdit().returnPressed.connect(self.comboboxAddReturnPressed)
        self.get_songAllGenres()
        self.get_allGenres()
        self.set_list()
        
    def comboboxAddReturnPressed(self):
        self.on_buttonadd_clicked()
    
    def get_allGenres(self):
        """
        Übergibt alle Genres von allen Liedern.
        """
        self.c.execute('SELECT genre_name as genre FROM genre')
        self.genres = self.c.fetchall()
    
    def get_songAllGenres(self):
        """
        Übergibt alle Genres des momentan ausgewählten Songes.
        """
        self.c.execute('''SELECT genre.genre_name as genre, genre.genre_ID as ID FROM genre 
                                                JOIN music_genre 
                                                    ON genre.genre_ID = music_genre.genre_ID 
                                                    WHERE music_genre.music_path = ?''', (self.path, ))
        self.Sgenres = self.c.fetchall()
    
    def set_list(self):
        """
        Erstellt die Listen, welche in den Comboboxes zu finden sind.
        """
        genres_name = QStringList()
        Sgenres_name = QStringList()
        
        for genre in self.Sgenres:
            if genre['genre'] != "empty":
                Sgenres_name.append(QString(genre['genre']))
        self.comboboxdel.addItems(Sgenres_name)
    
        for genre in self.genres:
            if not Sgenres_name.contains(QString(genre['genre'])):
                if genre['genre'] != "empty":
                    genres_name.append(QString(genre['genre']))
        self.comboboxadd.addItems(genres_name)
        
    def genreExists(self, genre):
        """
        Überprüft ob Genre bereits existiert.
        """
        self.c.execute('SELECT genre_ID FROM genre WHERE genre_name = ?',  (genre, ))
        exist = self.c.fetchone()
        if exist:
            return True
        else:
            return False
    
    def genreIsNeeded(self, genre):
        """
        Überprüft ob Genre gebraucht wird.
        """
        self.c.execute('SELECT * FROM genre JOIN music_genre ON music_genre.genre_ID = genre.genre_ID WHERE genre.genre_name = ?', (genre, ))
        if self.c.fetchone():
            return True
        else:
            return False
    
    @pyqtSignature("")
    def on_buttondel_clicked(self):
        """
        Genre wird vom Song entfernt und wenn es nicht mehr gebraucht wird, komplett gelöscht.
        """
        if self.comboboxdel.currentText():
            currentText = unicode(self.comboboxdel.currentText())
            self.c.execute('SELECT genre_ID FROM genre WHERE genre_name = ?',  (currentText, ))
            delgenreID = self.c.fetchone()['genre_ID']
            delete = (self.path, delgenreID)
            self.c.execute('DELETE FROM music_genre WHERE music_path = ? AND genre_ID = ?',  delete)
            self.conn.commit()
            
            if not self.genreIsNeeded(currentText):
                self.c.execute('DELETE FROM genre WHERE genre_name = ?', (currentText, ))
                self.conn.commit()
                self.comboboxdel.removeItem(self.comboboxdel.currentIndex())
            else:
                self.comboboxadd.addItem(QString(currentText))
                self.comboboxdel.removeItem(self.comboboxdel.currentIndex())
                
            if not self.comboboxdel.currentText():
                self.c.execute('''SELECT genre_ID from genre WHERE genre_name = "empty" ''')
                genre_ID = self.c.fetchone()['genre_ID']
                inserts = (self.path, genre_ID)
                self.c.execute('INSERT INTO music_genre VALUES(?,?)', inserts)
                self.conn.commit()
    
    @pyqtSignature("")
    def on_buttonadd_clicked(self):
        """
        Genre wird dem Song hinzugefügt und falls es noch nixht existierte, erstellt.
        """
        if self.comboboxadd.currentText():
            if not self.comboboxdel.currentText():
                self.c.execute('''SELECT genre_ID FROM genre WHERE genre_name = "empty" ''')
                delgenreID = self.c.fetchone()['genre_ID']
                delete = (self.path, delgenreID)
                self.c.execute('DELETE FROM music_genre WHERE music_path = ? AND genre_ID = ?',  delete)
                self.conn.commit()
                
                
            currentText = unicode(self.comboboxadd.currentText())
            if not self.genreExists(currentText):
                genreadd = (None, currentText)
                self.c.execute('''INSERT INTO genre VALUES (?,?) ''',  genreadd)
                self.conn.commit()
                
            if self.comboboxdel.findText(currentText) < 0:
                self.c.execute('SELECT genre_ID from genre WHERE genre_name = ?', (currentText, ))
                genre_ID = self.c.fetchone()['genre_ID']
                inserts = (self.path, genre_ID)
                self.c.execute('INSERT INTO music_genre VALUES(?,?)', inserts)
                self.conn.commit()
                self.comboboxdel.addItem(currentText)
                self.comboboxadd.clearEditText()
                self.comboboxadd.removeItem(self.comboboxadd.currentIndex())
    
    @pyqtSignature("")
    def on_buttonfinish_clicked(self):
        """
        Schliesst den Dialog.
        """
        self.close()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/cch/Documents/python/music manager/search.ui'
#
# Created: Wed May 27 11:18:03 2015
#      by: PyQt4 UI code generator 4.10.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName(_fromUtf8("Dialog"))
        Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
        Dialog.resize(337, 98)
        Dialog.setMinimumSize(QtCore.QSize(337, 98))
        Dialog.setMaximumSize(QtCore.QSize(337, 98))
        self.gridLayout_2 = QtGui.QGridLayout(Dialog)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.gridLayout = QtGui.QGridLayout()
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.lineEditPath = QtGui.QLineEdit(Dialog)
        self.lineEditPath.setObjectName(_fromUtf8("lineEditPath"))
        self.gridLayout.addWidget(self.lineEditPath, 0, 0, 1, 1)
        self.directoryPath = QtGui.QPushButton(Dialog)
        self.directoryPath.setObjectName(_fromUtf8("directoryPath"))
        self.gridLayout.addWidget(self.directoryPath, 0, 1, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)
        self.buttonBox = QtGui.QDialogButtonBox(Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.gridLayout_2.addWidget(self.buttonBox, 1, 0, 1, 1)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(_translate("Dialog", "Ordner suchen", None))
        self.directoryPath.setText(_translate("Dialog", "Browse", None))


if __name__ == "__main__":
    import sys
    app = QtGui.QApplication(sys.argv)
    Dialog = QtGui.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())

